@@ -13,7 +13,10 @@ class NeverGradAlgoWrapper():
 
     def create(self, metric, mode, search_space, **args):
         search_space = NeverGradSpace(search_space).get_search_space()
-        method = default_method if 'method' not in args else args['method']
+        if ('method' in args) and (args['method']):
+            method = args['method']
+        else:
+            method = default_method
         optimizer = ng.optimizers.registry[method](
                 parametrization=search_space, budget=default_budget)
         self.algorithm = NevergradSearch(optimizer, None, metric=metric, mode=mode, **args)
