@@ -4,6 +4,7 @@ import json
 import time
 import importlib
 import argparse
+from datetime import datetime
 from pdb import set_trace
 
 import ray
@@ -120,9 +121,10 @@ class JobHandler():
     def save_metadata(self, df, summary={}):
         hyperparameters = {key:key.replace('config/','') for key in df if 'config/' in key}
         df = df.rename(columns=hyperparameters)
+        df = df.rename(columns={'time_total_s':'time_s'})
         hp_raw = list(hyperparameters.keys())
         hp = list(hyperparameters.values())
-        columns_to_save = ['time_total_s']
+        columns_to_save = ['time_s']
         columns_to_save.extend(hp)
         if 'metric' in summary:
             columns_to_save.append(summary['metric'])
@@ -134,7 +136,8 @@ class JobHandler():
         with open(kGridSiteMetadataFileName,'w') as output:
             json.dump(summary, output)
 
-    def get_resource_info(self):
+    @staticmethod
+    def get_resource_info():
         resource = {}
         n_gpu = helper.get_n_gpu()
         n_cpu = helper.get_n_cpu()
@@ -174,13 +177,15 @@ class JobHandler():
             hpo_config['mode'],
             search_space, **hpo_config['scheduler_param'])
 
-        resources_per_trial = self.get_resource_info()
+        resources_per_trial = JobHandler.get_resource_info()
 
         model = self.get_model( model_config['script'], model_config['model'])
 
         #ray.init(node_ip_address="127.0.0.1", ignore_reinit_error=True)
         ray.init(ignore_reinit_error=True)
 
+        start_data_time = datetime.now().strftime("%m/%d/%Y, %H:%M:%S")
+
         analysis = tune.run(
             model,
             name=proj_name,
@@ -196,6 +201,8 @@ class JobHandler():
 
         end = time.time()
         total_time = float(end-start)
+        end_data_time = datetime.now().strftime("%m/%d/%Y, %H:%M:%S")
+
         best_config = analysis.get_best_config(metric=hpo_config['metric'], mode = hpo_config['mode'])
         print("Best config: ", best_config)
         print("Time taken in seconds: ", total_time)
@@ -204,10 +211,12 @@ class JobHandler():
 
         summary = {
             'title' : proj_name,
+            'start_date_time': start_data_time,
+            'end_date_time': end_data_time,
+            'task_time_s' : total_time,
             'metric': hpo_config['metric'],
             'mode' : hpo_config['mode'],
-            'best_config' : best_config,
-            'task_time_s' : total_time
+            'best_config' : best_config, 
         }
 
         self.save_metadata(df, summary)
