@@ -45,4 +45,4 @@ kDefaultOutDS = 'user.${{RUCIO_ACCOUNT}}.hpogrid.{HPO_PROJECT_NAME}.out.$(date +
 
 kGridSiteMetadataFileName = 'userJobMetadata.json'
 
-kHPOGridMetadataFormat = ['title', 'metric', 'mode', 'task_time_s', 'result', 'hyperparameters', 'best_config']
+kHPOGridMetadataFormat = ['title', 'metric', 'mode', 'task_time_s', 'result', 'hyperparameters', 'best_config', 'start_date_time', 'end_date_time']
