@@ -3,8 +3,7 @@
 """
 from tabulate import tabulate
 import pandas as pd
-
-version = '0.1.2'
+from pdb import set_trace
 
 kDefaultTableStyle = 'psql'
 kDefaultStrAlign = 'left'
@@ -26,6 +25,7 @@ def create_table(data, columns=None, indexed=True, transpose=False,
 	df = pd.DataFrame(data, columns=columns)
 	if transpose:
 		df = df.transpose()
+	set_trace()
 	table = tabulate(df, showindex=indexed, headers=df.columns, 
 	    tablefmt=tableformat,
 	    stralign=stralign)
